@@ -3,7 +3,7 @@ from fastmcp.server.auth.providers.jwt import StaticTokenVerifier
 from fastmcp.server.auth.providers.jwt import JWTVerifier
 from fastmcp import FastMCP
 from fastmcp.prompts.prompt import PromptMessage, TextContent
-from agentmake import agentmake, DEVELOPER_MODE, DEFAULT_AI_BACKEND
+from agentmake import agentmake, DEVELOPER_MODE
 from biblemate import BIBLEMATE_VERSION, BIBLEMATEDATA, AGENTMAKE_CONFIG, config
 from biblemate.uba.bible import search_bible
 from biblemate.uba.api import run_uba_api, run_uba_ai_commentary, run_uba_words, run_uba_discourse, run_uba_translation, run_uba_index
@@ -13,8 +13,9 @@ from typing import List, Dict, Any, Union
 parser = argparse.ArgumentParser(description = f"""BibleMate AI {BIBLEMATE_VERSION} CLI options""")
 parser.add_argument("-b", "--backend", action="store", dest="backend", help="AI backend; overrides the default backend temporarily.")
 args = parser.parse_args()
-THIS_BACKEND = args.backend if args.backend else DEFAULT_AI_BACKEND
-THIS_BACKEND = config.backend if not config.backend == DEFAULT_AI_BACKEND else THIS_BACKEND
+THIS_BACKEND = args.backend if args.backend else os.getenv("DEFAULT_AI_BACKEND") if os.getenv("DEFAULT_AI_BACKEND") else "googleai"
+if not config.backend == THIS_BACKEND:
+    THIS_BACKEND = config.backend
 
 # configure backend
 AGENTMAKE_CONFIG["backend"] = THIS_BACKEND
