@@ -2,7 +2,7 @@ from biblemate.core.systems import *
 from biblemate.uba.dialogs import *
 from biblemate.ui.text_area import getTextArea
 from biblemate.ui.info import get_banner
-from biblemate import config, DIALOGS, BIBLEMATE_VERSION, AGENTMAKE_CONFIG, BIBLEMATE_USER_DIR, BIBLEMATEDATA, fix_string, write_user_config, list_dir_content
+from biblemate import config, CONFIG_FILE_BACKUP, DIALOGS, BIBLEMATE_VERSION, AGENTMAKE_CONFIG, BIBLEMATE_USER_DIR, BIBLEMATEDATA, fix_string, write_user_config, list_dir_content
 from biblemate.uba.api import DEFAULT_MODULES, run_uba_api
 from pathlib import Path
 import urllib.parse
@@ -13,7 +13,7 @@ from fastmcp import Client
 from fastmcp.client.transports import StreamableHttpTransport
 from agentmake.plugins.uba.lib.BibleBooks import BibleBooks
 from agentmake.plugins.uba.lib.BibleParser import BibleVerseParser
-from agentmake import agentmake, getOpenCommand, getDictionaryOutput, edit_file, edit_configurations, extractText, readTextFile, writeTextFile, getCurrentDateTime, AGENTMAKE_USER_DIR, USER_OS, DEVELOPER_MODE, DEFAULT_AI_BACKEND, DEFAULT_TEXT_EDITOR
+from agentmake import agentmake, getOpenCommand, getDictionaryOutput, edit_file, edit_configurations, extractText, readTextFile, writeTextFile, getCurrentDateTime, AGENTMAKE_USER_DIR, USER_OS, DEVELOPER_MODE, DEFAULT_TEXT_EDITOR
 from agentmake.utils.files import searchFolder, isExistingPath
 from agentmake.etextedit import launch_async
 from agentmake.utils.manage_package import getPackageLatestVersion
@@ -56,14 +56,21 @@ if not sys.stdin.isatty():
         args.default = [stdin_text]
 
 # write to the `config.py` file temporarily for the MCP server to pick it up
-if args.backend:
-    with open(os.path.join(os.path.dirname(os.path.realpath(__file__)), "config.py"), "a", encoding="utf-8") as fileObj:
-        fileObj.write(f'''\nbackend="{args.backend}"''')
-    config.backend = args.backend
-else:
-    with open(os.path.join(os.path.dirname(os.path.realpath(__file__)), "config.py"), "a", encoding="utf-8") as fileObj:
-        fileObj.write(f'''\nbackend="{DEFAULT_AI_BACKEND}"''')
-    config.backend = DEFAULT_AI_BACKEND
+config.backend = args.backend if args.backend else os.getenv("DEFAULT_AI_BACKEND") if os.getenv("DEFAULT_AI_BACKEND") else "googleai"
+with open(CONFIG_FILE_BACKUP, "a", encoding="utf-8") as fileObj:
+    fileObj.write(f'''\nconfig.backend="{config.backend}"''')
+
+AGENTMAKE_ENV_PATH = os.path.join(AGENTMAKE_USER_DIR, "agentmake.env")
+if config.backend == "googleai" and not os.getenv("GOOGLEAI_API_KEY") and os.path.isfile(AGENTMAKE_ENV_PATH):
+    googleai_api_key = DIALOGS.getInputDialog_sync(title="Google AI API key", text="Enter your Google AI API key:")
+    if googleai_api_key.strip():
+        googleai_api_key = googleai_api_key.strip()
+        agentmake_env_content = readTextFile(AGENTMAKE_ENV_PATH)
+        if "\nGOOGLEAI_API_KEY=" in agentmake_env_content:
+            writeTextFile(AGENTMAKE_ENV_PATH, re.sub("\nGOOGLEAI_API_KEY=[^\n]*?\n", f'\nGOOGLEAI_API_KEY="{googleai_api_key}"\n', agentmake_env_content))
+        else:
+            with open(AGENTMAKE_ENV_PATH, "a", encoding="utf-8") as fileObj:
+                fileObj.write(f'''\nGOOGLEAI_API_KEY="{googleai_api_key}"\n''')
 
 AGENTMAKE_CONFIG["backend"] = config.backend
 DEFAULT_SYSTEM = "You are BibleMate AI, an autonomous agent designed to assist users with their Bible study."
@@ -293,8 +300,6 @@ async def main_async():
         client = Client(mcp_server) # no auth for stdio transport
 
     APP_START = True
-    DEFAULT_SYSTEM = "You are BibleMate AI, an autonomous agent designed to assist users with their Bible study."
-    DEFAULT_MESSAGES = [{"role": "system", "content": DEFAULT_SYSTEM}, {"role": "user", "content": "Hello!"}, {"role": "assistant", "content": "Hello! I'm BibleMate AI, your personal assistant for Bible study. How can I help you today?"}] # set a tone for bible study; it is userful when auto system is used.
 
     async with client:
 
@@ -357,7 +362,7 @@ async def main_async():
                     TextColumn("[progress.description]{task.description}"),
                     transient=True  # This makes the progress bar disappear after the task is done
                 ) as progress:
-                    task_id = progress.add_task(description if description else "Thinking ...", total=None)
+                    task_id = progress.add_task((description if description else "Thinking ...")+" [`Ctrl+C` to cancel]", total=None)
                     async_task = asyncio.create_task(process())
                     try:
                         while not async_task.done():
@@ -373,7 +378,7 @@ async def main_async():
                 """
                 A coroutine that runs a progress bar while awaiting a task.
                 """
-                with alive_bar(title="Processing...", spinner='dots') as bar:
+                with alive_bar(title="Processing ...", spinner='dots') as bar:
                     while not task.done():
                         bar() # Update the bar
                         await asyncio.sleep(0.02) # Yield control back to the event loop
@@ -383,7 +388,9 @@ async def main_async():
                 Manages the async task and the progress bar.
                 """
                 if step_number:
-                    print(f"# Starting Step [{step_number}]...")
+                    print(f"# Starting Step [{step_number}] ... [`Ctrl+C` to cancel]")
+                else:
+                    print(f"# Getting started ... [`Ctrl+C` to cancel]")
                 # Create the async task but don't await it yet.
                 task = asyncio.create_task(run_tool(tool, tool_instruction))
                 # Await the custom async progress bar that awaits the task.
@@ -785,11 +792,11 @@ https://github.com/eliranwong/biblemate
 - `Ctrl+DOWN`: scroll down
 - `Shift+TAB`: insert four spaces
 - `TAB` or `Ctrl+I`: open input suggestion menu
-- `Esc`: close input suggestion menu
+- `Esc+Esc`: close input suggestion menu
 
-## Cancel Loading an AI response
+## Cancel Running Operations
 
-Press `Ctrl+C` once or twice until the loading is cancelled, while you are waiting for a response."""
+Press `Ctrl+C` once or twice until the running process is cancelled, while you are waiting for a response."""
                     display_info(console, Markdown(help_info), title="Help")
                 elif user_request == ".tools":
                     enabled_tools = await DIALOGS.getMultipleSelection(
@@ -1170,7 +1177,7 @@ Press `Ctrl+C` once or twice until the loading is cancelled, while you are waiti
                         messages.append({"role": "assistant", "content": tool_result if tool_result.strip() else "Tool error!"})
                     except Exception as e:
                         if DEVELOPER_MODE:
-                            console.print(f"Error: {e}\nFallback to direct response...\n\n")
+                            console.print(f"Error: {e}\nFallback to direct response ...\n\n")
                             print(traceback.format_exc())
                         messages = agentmake(messages, system="auto", **AGENTMAKE_CONFIG)
                 messages[-1]["content"] = fix_string(messages[-1]["content"])
@@ -1508,7 +1515,7 @@ You provide the converted instruction directly, without any additional commentar
                 config.backup_required = False
     
     # back up configurations
-    write_user_config(backup=True)
+    #write_user_config()
     # reset terminal window title
     clear_title()
 
